@@ -39,6 +39,7 @@ static void load_state_from_file(FILE *ifp) {
 	char* wav_name = malloc (nbytes + 1);
 	char* png_name = malloc (nbytes + 1);
 
+	ClutterActor* track_view = NULL; //Will be jammo_trac_view or jammo_miditrack_view
 	while (not_ready) {
 
 		bytes_read = getline (&my_string, &nbytes, ifp);
@@ -47,7 +48,6 @@ static void load_state_from_file(FILE *ifp) {
 			not_ready=FALSE;
 			continue;
 		}
-		ClutterActor* track_view = NULL; //Will be jammo_trac_view or jammo_miditrack_view
 
 		if(strncmp(my_string, "Track-type:", 11) == 0) {
 			printf("New track.\n");
@@ -102,8 +102,11 @@ static void load_state_from_file(FILE *ifp) {
 						ClutterActor* sample_button;
 						sample_button = jammo_sample_button_new_from_files(png_name, wav_name);
 						printf("Sample button created\n");
-						jammo_track_view_add_jammo_sample_button(JAMMO_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(sample_button), slot);
 
+						if (track_view == NULL)
+							printf("Can't put sample because track is NULL\n");
+						else
+							jammo_track_view_add_jammo_sample_button(JAMMO_TRACK_VIEW(track_view),JAMMO_SAMPLE_BUTTON(sample_button), slot);
 						}
 			}
 	}
