@@ -29,6 +29,9 @@ static gems_components* gems_data = NULL;
 // empty callbacks for CHUM. These are used to avoid problems when calling an unset callback
 static void empty_callback_add_loop_to_slot(GObject * game, guint user_id, guint id, guint slot){}
 static void empty_callback_remove_loop_from_slot(GObject * game, guint user_id, guint slot){}
+static void empty_callback_midi_list(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list){}
+static void empty_callback_slider_event_list(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list){}
+static void empty_callback_group_control(gint type){}
 
 // A "singleton" get
 gems_components* gems_get_data()
@@ -210,6 +213,9 @@ void jammo_gems_init(int argc, char* argv[])
 	//Init CHUM Callbacks.
 	chum_callback_add_loop_to_slot=empty_callback_add_loop_to_slot;
 	chum_callback_remove_loop_from_slot=empty_callback_remove_loop_from_slot;
+	chum_callback_midi_list=empty_callback_midi_list;
+	chum_callback_slider_event_list=empty_callback_slider_event_list;
+	chum_callback_group_control=empty_callback_group_control;
 
 	logmsg = g_strdup_printf("jammo_gems_init: done");
 	cem_add_to_log(logmsg,LOG_DEBUG);
@@ -763,6 +769,17 @@ void gems_set_callback_remove_loop(void (*func_ptr)(GObject * game, guint user_i
 	chum_callback_remove_loop_from_slot=func_ptr;
 }
 
+void gems_set_callback_midi_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) ) {
+	chum_callback_midi_list=func_ptr;
+}
+
+void gems_set_callback_slider_event_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) ) {
+	chum_callback_slider_event_list=func_ptr;
+}
+void gems_set_callback_group_control(void (*func_ptr)(gint type) ) {
+	chum_callback_group_control=func_ptr;
+}
+
 void gems_debugging_show_jammos()
 {
 	// get COPY of a list
