@@ -62,8 +62,14 @@ void gems_debugging_show_jammos();
 //CALLBACKS for CHUM
 void (*chum_callback_add_loop_to_slot)(GObject * game, guint user_id, guint id, guint slot);
 void (*chum_callback_remove_loop_from_slot)(GObject * game, guint user_id, guint slot);
+void (*chum_callback_midi_list)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list);
+void (*chum_callback_group_control)(gint type);
+void (*chum_callback_slider_event_list)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list);
 void gems_set_callback_add_loop(void (*func_ptr)(GObject * game, guint user_id, guint id, guint slot) );
 void gems_set_callback_remove_loop(void (*func_ptr)(GObject * game, guint user_id, guint slot) );
+void gems_set_callback_midi_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) );
+void gems_set_callback_slider_event_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) );
+void gems_set_callback_group_control(void (*func_ptr)(gint type) );
 
 void gems_init_peerhood_callback();
 void gems_enable_network_timeout_functions();
