@@ -472,9 +472,9 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element, element->add_position)));
 					for (; element->add_position < gems_connection_get_32(element, 2);) {
 						// note is a char. no need to do anything
-						element->add_position +=1;
+						element->add_position += sizeof(unsigned char);
 						// timestamp
-						gems_connection_add_64(element, g_ntohl(gems_connection_get_64(element, element->add_position)));
+						gems_connection_add_64(element, GUINT64_FROM_BE(gems_connection_get_64(element, element->add_position)));
 						// type
 						gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					}
@@ -486,9 +486,9 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					for (; element->add_position < gems_connection_get_32(element, 2);) {
 						// freq is float. it is received as an 32bit integer and localized to a float
 						// see add float and get float functions for details
-						gems_connection_add_float(element, ntohf(gems_connection_get_float(element, element->add_position)));
+						gems_connection_add_float(element, gems_connection_get_float_for_localization(element, element->add_position));
 						// timestamp
-						gems_connection_add_64(element, g_ntohl(gems_connection_get_64(element, element->add_position)));
+						gems_connection_add_64(element, GUINT64_FROM_BE(gems_connection_get_64(element, element->add_position)));
 						// type
 						gems_connection_add_32(element, g_ntohl(gems_connection_get_32(element, element->add_position)));
 					}
