@@ -14,6 +14,7 @@ License:LGPL 2.1
 #include <string.h>
 #include <gst/controller/gstcontroller.h>
 #include <sys/time.h>
+#include <sndfile.h>
 
 #include "../plugin-common.h"
 #include "gstjammosampler.h"
@@ -249,9 +250,9 @@ src->wav_based_instrument[index]->released=FALSE;
 src->wav_based_instrument[index]->releasecounter=-1.0;
 src->wav_based_instrument[index]->fade_out=fade_out;
 
-FILE * filepointer;
-	filepointer = fopen(filename, "r" );
-if (filepointer==NULL) {
+SF_INFO sfinfo;
+SNDFILE * sndfileptr = sf_open(filename, SFM_READ, &sfinfo);
+if (sndfileptr==NULL) {
 	printf("error opening file %s\n", filename);
 	exit(1);
 }
@@ -263,6 +264,15 @@ if (filepointer==NULL) {
 
 src->wav_based_instrument[index]->sampletable =NULL;
 
+// samplerate of sample file can be played with correct pitch even if samplerate of a file is
+// different from the samplerate of sampler
+src->wav_based_instrument[index]->original_samplerate=sfinfo.samplerate;
+
+// sampler is mono sampler
+if (sfinfo.channels>1) {
+	g_warning("Loading a multi-channel file to mono sampler.");
+}
+
 //printf("\nbefore looking for same sample\n");
 
 for (i=0;i<JAMMOMIDI_NUMBER_OF_NOTES;i++) {
@@ -289,12 +299,12 @@ if (src->wav_based_instrument[index]->sampletable ==NULL) {
 		src->wav_based_instrument[index]->filename =realloc(src->wav_based_instrument[index]->filename, (strlen(filename)+1)*sizeof(gchar) );
 	strcpy(src->wav_based_instrument[index]->filename, filename);
 	/* read audio data to sample table */
-	if (!fread(src->wav_based_instrument[index]->sampletable,1,file_size*2,filepointer)){
-		printf("error reading raw-audio\n");
+	if (sf_read_short(sndfileptr, src->wav_based_instrument[index]->sampletable, file_size)!=file_size){
+		printf("error reading sample file\n");
 		}
 }
 
-fclose(filepointer);
+sf_close(sndfileptr);
 }
 
 
@@ -510,9 +520,9 @@ static gfloat looping_sampler(GstJammoSampler * src, gint j) {
 			/* Playing */
 			value=( interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
 			/* move sampleindex according to needed pitch */
-			/* 44100 is samplerate of sample files. value could be read from wav header and stored to i.e slicedWav->samplerate. then we would be able to used samples with different sample rates */
-	/* samplerate variable has the output samplerate of jammosampler */
-			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*44100/(src->samplerate+0.0);
+			/* samplerate variable has the output samplerate of jammosampler */
+			/* data from sound file is played with correct pitch by interpolating according to file's samplerate */
+			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
 
 			/* if note has been released after previous round */
 			if (src->wav_based_instrument[j]->released) {
@@ -596,9 +606,9 @@ static gfloat nonlooping_sampler(GstJammoSampler * src, gint j) {
 			/* Playing */
 			value=( interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
 			/* move sampleindex according to needed pitch */
-			/* 44100 is samplerate of sample files. value could be read from wav header and stored to i.e slicedWav->samplerate. then we would be able to used samples with different sample rates */
 			/* samplerate variable has the output samplerate of jammosampler */
-			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*44100/(src->samplerate+0.0);
+			/* data from sound file is played with correct pitch by interpolating according to file's samplerate */
+			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
 
 			/* if note has been released after previous round */
 			if (src->wav_based_instrument[j]->released) {
@@ -664,9 +674,9 @@ static gfloat oneshot_sampler(GstJammoSampler * src, gint j) {
 			/* Playing */
 			value=( interpolation(*sampleindex-(gint)*sampleindex, sampletable[(gint)*sampleindex], sampletable[((gint)*sampleindex+1)]) /(G_MAXINT16*1.0) * scale );
 			/* move sampleindex according to needed pitch */
-			/* 44100 is samplerate of sample files. value could be read from wav header and stored to i.e slicedWav->samplerate. then we would be able to used samples with different sample rates */
 			/* samplerate variable has the output samplerate of jammosampler */
-			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*44100/(src->samplerate+0.0);
+			/* data from sound file is played with correct pitch by interpolating according to file's samplerate */
+			src->wav_based_instrument[j]->sampleindex += pitch(src->wav_based_instrument[j]->needed_pitch)*src->wav_based_instrument[j]->original_samplerate/(src->samplerate+0.0);
 
 			/* fade in to prevent clicks and pops*/
 			if (*sampleindex<50) {
